<?php

/**
 * バージョン番号
 */

define('THEME_VERSION_ID', '1.0.1');



/**
 * カスタムファンクション
 */

$custom_functions_files = array(
  'inc/customizer',
  'inc/widget_recent-post-plus',
  'inc/dynamic-sidebar',
  'inc/replace',
);

foreach ( $custom_functions_files as $custom_functions_file ) {
  get_template_part( $custom_functions_file );
}



/**
 * JavaScript 読み込み
 */

function theme_scripts_setup() {
  wp_enqueue_script( 'jquery' );
  
  wp_enqueue_script(
    'stepress-script',
    get_template_directory_uri() . '/js/script.min.js',
    array( 'jquery' ),
    THEME_VERSION_ID, true
  );
  
  if ( is_singular() ) {
    wp_enqueue_script( 'comment-reply' );
  }
}

add_action( 'wp_enqueue_scripts', 'theme_scripts_setup' );


/**
 * カスタムメニュー
 */

add_theme_support('menus' );

register_nav_menus( array(
  'header-menu' => __( 'メインメニュー', 'stepress' ),
  'extra-menu'  => __( '右上のメニュー', 'stepress' ),
  'footer-menu' => __( 'フッターメニュー', 'stepress' ),
));


/**
 * アイキャッチサムネイル
 */

add_theme_support( 'post-thumbnails' );



/**
 * 固定ページで抜粋を有効にする
 */

add_post_type_support( 'page', 'excerpt' );



/**
 * 画像URLから画像IDを取得
 */

function get_image_id( $image_url ) {
	global $wpdb;
	$attachment = $wpdb->get_col( $wpdb->prepare( "SELECT ID FROM $wpdb->posts WHERE guid='%s';", $image_url ) );
  return $attachment[0];
}



/**
 * title タグ
 */

function theme_slug_setup() {
  add_theme_support( 'title-tag' );
}

add_action( 'after_setup_theme', 'theme_slug_setup' );



/**
 * description タグ
 */

function get_description() {
  $description = '';

  if ( is_singular() ) {
		while ( have_posts() ) {
		  the_post();
			$description = strip_tags( get_the_excerpt() );
		}
	} elseif ( is_category() ) {
  	if ( empty( category_description() ) ) {
    	$description = 'カテゴリー「' . single_cat_title('', false ) . '」の記事一覧です。';
  	} else {
  		$description = strip_tags( category_description() );
  	}
	} elseif ( is_tag() ) {
  	if ( empty( tag_description() ) ) {
    	$description = 'タグ「' . single_tag_title('', false ) . '」の記事一覧です。';
  	} else {
  		$description = strip_tags( tag_description() );
  	}
  } else {
    $description = get_bloginfo( 'description' );
  }

  return $description;
}

add_action( 'wp_head', 'get_description' );




