<!DOCTYPE html>
<html <?php language_attributes(); ?>>
  <head>
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta charset="<?php bloginfo( 'charset' ); ?>" />
    <meta name="format-detection" content="telephone=no" />
    <meta name="viewport" content="maximum-scale=1, initial-scale=1.0">
    <meta name="description" content="<?php echo get_description(); ?>">
    <link rel="stylesheet" href="<?php echo get_template_directory_uri(); ?>/icon/style.css?ver.<?php echo THEME_VERSION_ID; ?>" type="text/css" media="all" />
    <link rel="stylesheet" href="<?php echo get_template_directory_uri(); ?>/style.css?ver.<?php echo THEME_VERSION_ID; ?>" type="text/css" media="all" />
    <link rel="alternate" type="application/rss+xml" title="<?php bloginfo( 'name' ); ?> RSS Feed" href="<?php bloginfo( 'rss2_url' ); ?>" />
    <?php get_template_part( 'template-parts/customizer-css' ); ?>
    <?php wp_head(); ?>
  </head>



  <body id="stepress" <?php body_class( 'layout-' . get_theme_mod( 'customize_layout_type', 'a' ) ); ?>>

    <?php if ( get_theme_mod( 'customize_layout_type', 'a' ) == 'b' ): // レイアウトタイプB ?>
      <div class="container">
    <?php endif; ?>

    <!-- ヘッダー -->
    <header id="header" class="header" role="banner">
      <div class="header__top">
        <div class="header__top__container container">
          <div class="header__top__left">
            <?php
            // ロゴ画像の情報を取得
            $logo_url    = esc_url( get_theme_mod( 'customize_logo', false ) );
            $logo_id     = get_image_id( $logo_url );
            $logo        = wp_get_attachment_image_src( $logo_id, 'full' );
            $logo_width  = round( $logo[1] / 2 );
            $logo_height = round( $logo[2] / 2 );

            // Retina対応
            if ( get_theme_mod( 'customize_logo_retina', false ) ) {
              $logo_img_retina = ' header-logo__img--retina';
            }

            // スマートフォン用ロゴ画像の情報を取得
            if ( get_theme_mod( 'customize_logo_sp', false ) ) {
              $logo_sp_url    = esc_url( get_theme_mod( 'customize_logo_sp', false ) );
              $logo_sp_id     = get_image_id( $logo_sp_url );
              $logo_sp        = wp_get_attachment_image_src( $logo_sp_id, 'full' );
              $logo_sp_width  = round( $logo_sp[1] / 2 );
              $logo_sp_height = round( $logo_sp[2] / 2 );
              $logo_img_class = ' header-logo__img--pc';
            }

            // ロゴを囲むタグ：h1 or div
            if ( is_front_page() ||  is_search() ) {
              $header_tag = 'h1';
            } else {
              $header_tag = 'div';
            }
            ?>
            <<?php echo $header_tag; ?> class="header-logo">
              <?php
              if ( $logo_url ): // ロゴ画像あり
                ?>
                <a href="<?php echo home_url( '/' ); ?>" class="header-logo__pic">
                  <img src="<?php echo $logo_url; ?>"
                       width="<?php echo $logo_width; ?>"
                       height="<?php echo $logo_height; ?>"
                       alt="<?php bloginfo( 'name' ); ?>"
                       class="header-logo__img<?php echo $logo_img_class . $logo_img_retina; ?>">
                  <?php if ( get_theme_mod( 'customize_logo_sp', false ) ): ?>
                    <img src="<?php echo $logo_sp_url; ?>"
                         width="<?php echo $logo_sp_width; ?>"
                         height="<?php echo $logo_sp_height; ?>"
                         alt=""
                         class="header-logo__img header-logo__img--sp">
                  <?php endif; ?>
                </a>
              <?php else: // ロゴ画像なし ?>
                <a href="<?php echo home_url( '/' ); ?>" class="header-logo__text">
                  <?php bloginfo( 'name' ); ?>
                </a>
              <?php endif; ?>
            </<?php echo $header_tag; ?>>
          </div>

          <?php // 右上のメニュー
          if ( has_nav_menu( 'extra-menu' ) ): ?>
            <div class="header__top__right">
              <?php
              wp_nav_menu( array(
                'theme_location'  => 'extra-menu',
                'container'       => 'nav',
                'fallback_cb'     => '',
                'container_id'    => 'extra-menu',
                'container_class' => 'extra-menu',
                'menu_id'         => 'extra-menu__ul',
                'menu_class'      => 'extra-menu__ul',
                'depth'           => 2,
              ) ); ?>
            </div>
          <?php endif; ?>

          <?php // ページ内検索
          if ( get_theme_mod( 'customize_header_search_show', true ) ):?>
            <div class="header-search">
            	<form id="header-search__form" class="header-search__form" method="get" action="<?php echo home_url(); ?>/">
              	<div class="header-search__input">
              		<input type="text" name="s" value="<?php the_search_query(); ?>">
                </div>
            	</form>
            	<div class="header-search__button"></div>
            </div>
          <?php endif; ?>
        </div>
      </div>

      <?php
      // カスタマイザー設定：折り返し
      switch ( get_theme_mod( 'customize_hmenu_style_sp', 2 ) ) {
        case 1:
          $customize_menu = 'header__bottom--drawer';
          break;
        case 2:
          $customize_menu = 'header-menu-wrap header-menu-wrap--2';
          break;
        case 3:
          $customize_menu = 'header-menu-wrap header-menu-wrap--3';
          break;
        case 4:
          $customize_menu = 'header-menu-wrap header-menu-wrap--4';
          break;
        default:
          $customize_menu = 'header-menu-wrap--0';
          break;
      }
      ?>
     <?php if ( has_nav_menu( 'header-menu' ) ): ?>
       <div class="header__bottom <?php echo $customize_menu ?>">
          <div class="container">
            <?php // メインメニュー
            wp_nav_menu( array(
              'theme_location'  => 'header-menu',
              'container'       => 'nav',
              'fallback_cb'     => '',
              'container_id'    => 'header-menu',
              'container_class' => 'header-menu',
              'menu_id'         => 'header-menu__list',
              'menu_class'      => 'header-menu__list',
              'depth'           => 2,
            ) ); ?>
          </div>
        </div>
      <?php endif; ?>
    </header>



    <?php if ( is_front_page() && !is_paged() ): // トップページのみ ?>
      <?php
      // カバー画像
      $cover_url     = esc_url( get_theme_mod( 'customize_cover', false ) );

      // タブレット用のカバー画像
      $cover_tab_url = esc_url( get_theme_mod( 'customize_cover_tab', false ) );

      // スマートフォン用のカバー画像
      $cover_sp_url  = esc_url( get_theme_mod( 'customize_cover_sp', false ) );

      // リンク
      $cover_link    = esc_url( get_theme_mod( 'customize_cover_link', false ) );

      // リンクターゲット
      if ( get_theme_mod( 'customize_cover_link_target', false ) ) {
        $cover_link_target = 'target="_blank"';
      }
      ?>
      <?php if ( get_theme_mod( 'customize_cover', false ) ): ?>
        <!-- カバー画像 -->
        <div class="cover container">
          <?php if ( $cover_link ): // リンクがある場合 ?>
            <a href="<?php echo $cover_link; ?>" <?php echo $cover_link_target; ?>>
          <?php endif; ?>
              <picture>
                <?php if ( $cover_sp_url ): ?>
                  <source media="(max-width: 600px)" srcset="<?php echo $cover_sp_url; ?>">
                <?php endif; ?>
                <?php if ( $cover_tab_url ): ?>
                  <source media="(max-width: 960px)" srcset="<?php echo $cover_tab_url; ?>">
                <?php endif; ?>
                <img src="<?php echo $cover_url; ?>" alt="">
              </picture>
          <?php if ( $cover_link ): // リンクがある場合 ?>
            </a>
          <?php endif; ?>
        </div>
      <?php endif; ?>
    <?php endif; ?>



    <!-- コンテンツ -->
    <div class="contents-wrapper">

      <?php
      // パンくずリスト
      if ( get_theme_mod( 'customize_breadcrumb', true ) && !is_front_page() ) {
        get_template_part( 'template-parts/breadcrumb' );
      }

      // カスタマイザー設定：サイドバー非表示
      if ( get_theme_mod( 'customize_sidebar' ) == 'none' ) {
        $layout_single = 'contents-container--single';
      }
      ?>

      <div class="contents-container <?php echo $layout_single ?>">
        <div id="content" class="content">

