<?php

/*---------------------------------------------------------

　テーマカスタマイザー

---------------------------------------------------------*/


/**
 * 編集ショートカットを使用
 */

add_theme_support('customize-selective-refresh-widgets' );



/**
 * HTMLが使えるカスタムコントロールを追加
 */

if ( class_exists( 'WP_Customize_Control' ) && ! class_exists( 'Prefix_Custom_Content' ) ) {
  class Prefix_Custom_Content extends WP_Customize_Control {
  	public $content = '';
  	public function render_content() {
  		if ( isset( $this->label ) ) {
  			echo '<span class="customize-control-title">' . $this->label . '</span>';
  		}
  		if ( isset( $this->content ) ) {
  			echo $this->content;
  		}
  		if ( isset( $this->description ) ) {
  			echo '<span class="description customize-control-description">' . $this->description . '</span>';
  		}
  	}
  }
}



/**
 * テーマカスタマイザーにCSSを読み込み
 */

function stp_customize_style() {
  wp_enqueue_style( 'stp-style', get_template_directory_uri() . '/css/customizer.css' );
}
add_action( 'customize_controls_enqueue_scripts', 'stp_customize_style' );



/**
 * テーマカスタマイザーに項目を追加
 */

function stp_customize_register( $wp_customize) {

  // セクション追加
  $wp_customize->add_section('stp_image', array(
    'title'       => __( '画像', 'stepress' ),
    'priority'    => 35,
  ) );

  $wp_customize->add_section('stp_color', array(
    'title'       => __( '色', 'stepress' ),
    'priority'    => 36,
  ) );

  $wp_customize->add_section('stp_layout', array(
    'title'       => __( 'レイアウト', 'stepress' ),
    'priority'    => 37,
  ) );



  // セクション：画像

  // ロゴ画像
  // -----------------------------------------------------------------------------------------------
  $set = 'customize_title_logo';
  $wp_customize->add_setting( $set, array(
    'sanitize_callback' => 'sanitize_text_field',
  ) );
  $wp_customize->add_control( new Prefix_Custom_Content( $wp_customize, $set, array(
  	'label'       => __( '<div class="stp-title stp-title--first">ロゴ画像</div>', 'stepress' ),
  	'section'     => 'stp_image',
  ) ) );

	// ロゴ画像
	$set = 'customize_logo';
	$wp_customize->add_setting( $set );
	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, $set, array(
		'section'     => 'stp_image',
		'settings'    => $set,
	) ) );

  // Retina対応ロゴ
  $set = 'customize_logo_retina';
  $wp_customize->add_setting( $set, array(
    'default'     => false,
  ) );
  $wp_customize->add_control( $set, array(
    'label'       => __( 'Retina対応', 'stepress' ),
    'description' => __( '高精細ディスプレイ用に縮小表示します。', 'stepress' ),
    'section'     => 'stp_image',
    'settings'    => $set,
    'type'        => 'checkbox',
  ) );

  // 説明
  $set = 'customize_memo_logo';
  $wp_customize->add_setting( $set, array(
    'sanitize_callback' => 'sanitize_text_field',
  ) );
  $wp_customize->add_control( new Prefix_Custom_Content( $wp_customize, $set, array(
    'description' => __( '大きな画像はチェックを入れていなくてもヘッダーに合わせて縮小表示されます。ヘッダーの高さは<b>【レイアウト】</b>で変更できます。', 'stepress' ),
  	'section'     => 'stp_image',
  ) ) );

  // -----------------------------------------------------------------------------------------------

  $set = 'customize_hr_logo_sp';
  $wp_customize->add_setting( $set, array(
    'sanitize_callback' => 'sanitize_text_field',
  ) );
  $wp_customize->add_control( new Prefix_Custom_Content( $wp_customize, $set, array(
  	'label'       => '<hr>',
  	'section'     => 'stp_image',
  ) ) );

	// ロゴ画像：タブレット・スマートフォン用
  $set = 'customize_logo_sp';
	$wp_customize->add_setting( $set );
	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, $set, array(
		'label'       => __( 'タブレット・スマートフォン用', 'stepress' ),
    'description' => __( 'Retina対応', 'stepress' ),
		'section'     => 'stp_image',
		'settings'    => $set,
	) ) );

  // ロゴ画像：ヘッダーの高さに合わせる
  $set = 'customize_logo_height_sp';
  $wp_customize->add_setting( $set, array(
    'default'     => true,
  ) );
  $wp_customize->add_control( $set, array(
    'label'       => __( 'ヘッダーの高さに合わせる', 'stepress' ),
    'section'     => 'stp_image',
    'settings'    => $set,
    'type'        => 'checkbox',
  ) );


  // カバー画像
  // -----------------------------------------------------------------------------------------------
  $set = 'customize_title_cover';
  $wp_customize->add_setting( $set, array(
    'sanitize_callback' => 'sanitize_text_field',
  ) );
  $wp_customize->add_control( new Prefix_Custom_Content( $wp_customize, $set, array(
  	'label'       => __( '<div class="stp-title">カバー画像</div>', 'stepress' ),
  	'section'     => 'stp_image',
  ) ) );

	// カバー画像：デスクトップ
  $set = 'customize_cover';
	$wp_customize->add_setting( $set );
	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, $set, array(
		'section'     => 'stp_image',
		'settings'    => $set,
	) ) );

  // カバー画像：リンク先
  $set = 'customize_cover_link';
  $wp_customize->add_setting( $set, array(
    'default'     => '',
  ) );
  $wp_customize->add_control( $set, array(
		'description' => __( 'リンク先:', 'stepress' ),
    'section'     => 'stp_image',
    'settings'    => $set,
    'type'        => 'text',
  ) );

  // カバー画像：リンクを新しいタブで開く
  $set = 'customize_cover_link_target';
  $wp_customize->add_setting( $set, array(
    'default'     => false,
  ) );
  $wp_customize->add_control( $set, array(
    'label'       => __( 'リンクを新しいタブで開く', 'stepress' ),
    'section'     => 'stp_image',
    'type'        => 'checkbox',
    'settings'    => $set,
  ) );

  // -----------------------------------------------------------------------------------------------

  $set = 'customize_hr_cover_tab';
  $wp_customize->add_setting( $set, array(
    'sanitize_callback' => 'sanitize_text_field',
  ) );
  $wp_customize->add_control( new Prefix_Custom_Content( $wp_customize, $set, array(
  	'label'       => '<hr>',
  	'section'     => 'stp_image',
  ) ) );

	// カバー画像：タブレット用
  $set = 'customize_cover_tab';
	$wp_customize->add_setting( $set );
	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, $set, array(
		'label'       => __( 'タブレット用', 'stepress' ),
		'section'     => 'stp_image',
		'settings'    => $set,
	) ) );

	// カバー画像：スマートフォン用
  $set = 'customize_cover_sp';
	$wp_customize->add_setting( $set );
	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, $set, array(
		'label'       => __( 'スマートフォン用', 'stepress' ),
		'section'     => 'stp_image',
		'settings'    => $set,
	) ) );


  // 背景画像
  // -----------------------------------------------------------------------------------------------
  $set = 'customize_title_bg_image';
  $wp_customize->add_setting( $set, array(
    'sanitize_callback' => 'sanitize_text_field',
  ) );
  $wp_customize->add_control( new Prefix_Custom_Content( $wp_customize, $set, array(
  	'label'       => __( '<div class="stp-title">背景画像</div>', 'stepress' ),
 		'description' => __( 'レイアウトタイプによっては表示されません。', 'stepress' ),
  	'section'     => 'stp_image',
 ) ) );

	// 背景画像
  $set = 'customize_bg_image';
	$wp_customize->add_setting( $set );
	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, $set, array(
		//'label'       => __( '背景画像', 'stepress' ),
		'section'     => 'stp_image',
		'settings'    => $set,
	) ) );

  // 背景画像：繰り返し方法
  $set = 'customize_bg_image_repeat';
  $wp_customize->add_setting( $set, array(
    'default'     => 'repeat',
  ) );
  $wp_customize->add_control( $set, array(
    'label'       => __( 'リピート', 'stepress' ),
    'section'     => 'stp_image',
    'type'        => 'select',
    'settings'    => $set,
		'choices' => array(
			'repeat'    => __( '繰り返す', 'stepress' ),
			'repeat-x'  => __( 'ヨコ方向に繰り返す', 'stepress' ),
			'repeat-y'  => __( 'タテ方向に繰り返す', 'stepress' ),
			'no-repeat' => __( '繰り返さない', 'stepress' ),
		),
  ) );

  // 背景画像：タテ位置
  $set = 'customize_bg_image_position_y';
  $wp_customize->add_setting( $set, array(
    'default'     => 'top',
  ) );
  $wp_customize->add_control( $set, array(
    'label'       => __( 'タテ位置', 'stepress' ),
    'section'     => 'stp_image',
    'type'        => 'select',
    'settings'    => $set,
		'choices' => array(
			'top'    => __( '上', 'stepress' ),
			'center' => __( '中央', 'stepress' ),
			'bottom' => __( '下', 'stepress' ),
		),
  ) );

  // 背景画像：ヨコ位置
  $set = 'customize_bg_image_position_x';
  $wp_customize->add_setting( $set, array(
    'default'     => 'left',
  ) );
  $wp_customize->add_control( $set, array(
    'label'       => __( 'ヨコ位置', 'stepress' ),
    'section'     => 'stp_image',
    'type'        => 'select',
    'settings'    => $set,
		'choices' => array(
			'left'   => __( '左', 'stepress' ),
			'center' => __( '中央', 'stepress' ),
			'right'  => __( '右', 'stepress' ),
		),
  ) );

  // 背景画像：スクロール追従
  $set = 'customize_bg_image_attachment';
  $wp_customize->add_setting( $set, array(
    'default'     => 'fixed',
  ) );
  $wp_customize->add_control( $set, array(
    'label'       => __( 'スクロール追従', 'stepress' ),
    'section'     => 'stp_image',
    'type'        => 'select',
    'settings'    => $set,
		'choices' => array(
			'fixed'  => __( '固定', 'stepress' ),
			'scroll' => __( 'スクロール', 'stepress' ),
		),
  ) );


  // ヘッダー背景画像
  // -----------------------------------------------------------------------------------------------
  $set = 'customize_title_header_bg_image';
  $wp_customize->add_setting( $set, array(
    'sanitize_callback' => 'sanitize_text_field',
  ) );
  $wp_customize->add_control( new Prefix_Custom_Content( $wp_customize, $set, array(
  	'section'     => 'stp_image',
  	'label'       => __( '<div class="stp-title">ヘッダー背景画像</div>', 'stepress' ),
 ) ) );

	// ヘッダー背景画像
  $set = 'customize_header_bg_image';
	$wp_customize->add_setting( $set );
	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, $set, array(
		'section'     => 'stp_image',
		'settings'    => $set,
	) ) );

  // ヘッダー背景画像：繰り返し方法
  $set = 'customize_header_bg_image_repeat';
  $wp_customize->add_setting( $set, array(
    'default'     => 'repeat',
  ) );
  $wp_customize->add_control( $set, array(
    'label'       => __( 'リピート', 'stepress' ),
    'section'     => 'stp_image',
    'type'        => 'select',
    'settings'    => $set,
		'choices' => array(
			'repeat'    => __( '繰り返す', 'stepress' ),
			'repeat-x'  => __( 'ヨコ方向に繰り返す', 'stepress' ),
			'repeat-y'  => __( 'タテ方向に繰り返す', 'stepress' ),
			'no-repeat' => __( '繰り返さない', 'stepress' ),
		),
  ) );

  // 背景画像：タテ位置
  $set = 'customize_header_bg_image_position_y';
  $wp_customize->add_setting( $set, array(
    'default'     => 'top',
  ) );
  $wp_customize->add_control( $set, array(
    'label'       => __( 'タテ位置', 'stepress' ),
    'section'     => 'stp_image',
    'type'        => 'select',
    'settings'    => $set,
		'choices' => array(
			'top'    => __( '上', 'stepress' ),
			'center' => __( '中央', 'stepress' ),
			'bottom' => __( '下', 'stepress' ),
		),
  ) );

  // 背景画像：ヨコ位置
  $set = 'customize_header_bg_image_position_x';
  $wp_customize->add_setting( $set, array(
    'default'     => 'left',
  ) );
  $wp_customize->add_control( $set, array(
    'label'       => __( 'ヨコ位置', 'stepress' ),
    'section'     => 'stp_image',
    'type'        => 'select',
    'settings'    => $set,
		'choices' => array(
			'left'   => __( '左', 'stepress' ),
			'center' => __( '中央', 'stepress' ),
			'right'  => __( '右', 'stepress' ),
		),
  ) );


  // セクション：色

  // 基本項目
  // -----------------------------------------------------------------------------------------------
  $set = 'customize_group_basecolor';
  $wp_customize->add_setting( $set, array(
    'sanitize_callback' => 'sanitize_text_field',
  ) );
  $wp_customize->add_control( new Prefix_Custom_Content( $wp_customize, $set, array(
  	'label'       => __( '<div class="stp-title stp-title--first">基本項目</div>', 'stepress' ),
  	'section'     => 'stp_color',
  ) ) );

  // 背景色
  $set = 'customize_bgcolor';
  $wp_customize->add_setting( $set, array(
    'default'     => '#f9f9f9',
  ) );
  $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, $set, array(
    'label'       => __( '背景色', 'stepress' ),
    'section'     => 'stp_color',
   	'description' => __( '反映されないレイアウトタイプもあります。', 'stepress' ),
    'settings'    => $set,
  ) ) );

  // -----------------------------------------------------------------------------------------------

  $set = 'customize_hr_link_color';
  $wp_customize->add_setting( $set, array(
    'sanitize_callback' => 'sanitize_text_field',
  ) );
  $wp_customize->add_control( new Prefix_Custom_Content( $wp_customize, $set, array(
  	'section'     => 'stp_color',
  	'label'       => '<hr>',
  ) ) );

  // リンク色
  $set = 'customize_link_color';
  $wp_customize->add_setting( $set, array(
    'default'     => '#03a9f4',
  ) );
  $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, $set, array(
    'label'       => __( 'リンク色', 'stepress' ),
    'section'     => 'stp_color',
    'settings'    => $set,
  ) ) );

  // リンク色（訪問済み）
  $set = 'customize_link_visited_color';
  $wp_customize->add_setting( $set, array(
    'default'     => '#03a9f4',
  ) );
  $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, $set, array(
    'label'       => __( 'リンク色（訪問済み）', 'stepress' ),
    'section'     => 'stp_color',
    'settings'    => $set,
  ) ) );

  // リンク色（ホバー）
  $set = 'customize_link_hover_color';
  $wp_customize->add_setting( $set, array(
    'default'     => '#03a9f4',
  ) );
  $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, $set, array(
    'label'       => __( 'リンク色（ホバー）', 'stepress' ),
    'section'     => 'stp_color',
    'settings'    => $set,
  ) ) );


  // ヘッダー
  // -----------------------------------------------------------------------------------------------
  $set = 'customize_group_header';
  $wp_customize->add_setting( $set, array(
    'sanitize_callback' => 'sanitize_text_field',
  ) );
  $wp_customize->add_control( new Prefix_Custom_Content( $wp_customize, $set, array(
  	'section'     => 'stp_color',
  	'label'       => __( '<div class="stp-title">ヘッダー</div>', 'stepress' ),
  ) ) );

  // 背景色
  $set = 'customize_header_bgcolor';
  $wp_customize->add_setting( $set, array(
    'default'     => '#1e73be',
  ) );
  $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, $set, array(
    'label'       => __( '背景色', 'stepress' ),
    'section'     => 'stp_color',
    'settings'    => $set,
  ) ) );

  // 文字色（サイトのタイトル）
  $set = 'customize_header_title_color';
  $wp_customize->add_setting( $set, array(
    'default'     => '#fff',
  ) );
  $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, $set, array(
    'label'       => __( '文字色（サイトのタイトル）', 'stepress' ),
    'section'     => 'stp_color',
    'settings'    => $set,
  ) ) );

  // -----------------------------------------------------------------------------------------------

  $set = 'customize_hr_header_border_t_color';
  $wp_customize->add_setting( $set, array(
    'sanitize_callback' => 'sanitize_text_field',
  ) );
  $wp_customize->add_control( new Prefix_Custom_Content( $wp_customize, $set, array(
  	'section'     => 'stp_color',
  	'label'       => '<hr>',
  ) ) );

  // ヘッダー：ボーダー色（ヘッダーの上）
  $set = 'customize_header_border_t_color';
  $wp_customize->add_setting( $set, array(
    'default'     => '#fff',
  ) );
  $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, $set, array(
    'label'       => __( 'ボーダー色（ヘッダーの上）', 'stepress' ),
    'section'     => 'stp_color',
    'settings'    => $set,
  ) ) );

  // ヘッダー：ボーダー（ヘッダーの上）を表示する
  $set = 'customize_header_border_t_show';
  $wp_customize->add_setting( $set, array(
    'default'     => false,
  ) );
  $wp_customize->add_control( $set, array(
    'label'       => __( '表示する', 'stepress' ),
    'section'     => 'stp_color',
    'type'        => 'checkbox',
    'settings'    => $set,
  ) );

  // ヘッダー：ボーダー色（ヘッダーの下）
  $set = 'customize_hmenu_border_b_color';
  $wp_customize->add_setting( $set, array(
    'default'     => '#e1e1e1',
  ) );
  $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, $set, array(
    'label'       => __( 'ボーダー色（ヘッダーの下）', 'stepress' ),
    'section'     => 'stp_color',
    'settings'    => $set,
  ) ) );

  // ヘッダー：ボーダー（ヘッダーの下）を表示する
  $set = 'customize_hmenu_border_b_show';
  $wp_customize->add_setting( $set, array(
    'default'     => true,
  ) );
  $wp_customize->add_control( $set, array(
    'label'       => __( '表示する', 'stepress' ),
    'section'     => 'stp_color',
    'type'        => 'checkbox',
    'settings'    => $set,
  ) );


  // 右上のメニュー
  // -----------------------------------------------------------------------------------------------
  $set = 'customize_group_emenu_color';
  $wp_customize->add_setting( $set, array(
    'sanitize_callback' => 'sanitize_text_field',
  ) );
  $wp_customize->add_control( new Prefix_Custom_Content( $wp_customize, $set, array(
  	'section'     => 'stp_color',
  	'label'       => __( '<div class="stp-title">右上のメニュー</div>', 'stepress' ),
  	'description' => __( 'レイアウト設定で右上に表示できる<b>【検索アイコン】</b>やスマートフォンで左上に表示される<b>【ハンバーガーメニュー】</b>もこの文字色が反映されます。', 'stepress' ),
  ) ) );

  // 右上のメニュー：文字色
  $set = 'customize_emenu_color';
  $wp_customize->add_setting( $set, array(
    'default'     => '#fff',
  ) );
  $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, $set, array(
    'label'       => __( '文字色', 'stepress' ),
    'section'     => 'stp_color',
    'settings'    => $set,
  ) ) );

  // 右上のメニュー：文字色（ホバー）
  $set   = 'customize_emenu_hover_color';
  $wp_customize->add_setting( $set, array(
    'default'     => '#fff',
  ) );
  $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, $set, array(
    'label'       => __( '文字色（ホバー）', 'stepress' ),
    'section'     => 'stp_color',
    'settings'    => $set,
  ) ) );

  // 右上のメニュー：文字色（アクティブな項目）
  $set   = 'customize_emenu_on_color';
  $wp_customize->add_setting( $set, array(
    'default'     => '#fff',
  ) );
  $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, $set, array(
    'label'       => __( '文字色（アクティブな項目）', 'stepress' ),
    'section'     => 'stp_color',
    'settings'    => $set,
  ) ) );

  // -----------------------------------------------------------------------------------------------

  $set = 'customize_hr_emenu_border';
  $wp_customize->add_setting( $set, array(
    'sanitize_callback' => 'sanitize_text_field',
  ) );
  $wp_customize->add_control( new Prefix_Custom_Content( $wp_customize, $set, array(
  	'section'     => 'stp_color',
  	'label'       => '<hr>',
  ) ) );

  // 右上のメニュー：ボーダー色（アクティブな項目）
  $set   = 'customize_emenu_on_border_color';
  $wp_customize->add_setting( $set, array(
    'default'     => '#fff',
  ) );
  $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, $set, array(
    'label'       => __( 'ボーダー色（アクティブな項目）', 'stepress' ),
    'section'     => 'stp_color',
    'settings'    => $set,
  ) ) );

  // ↑を表示しない
  $set = 'customize_emenu_on_border_show';
  $wp_customize->add_setting( $set, array(
    'default'     => true,
  ) );
  $wp_customize->add_control( $set, array(
    'label'       => __( '表示する', 'stepress' ),
    'section'     => 'stp_color',
    'type'        => 'checkbox',
    'settings'    => $set,
  ) );


  // メインメニュー
  // -----------------------------------------------------------------------------------------------
  $set = 'customize_group_hmenu';
  $wp_customize->add_setting( $set, array(
    'sanitize_callback' => 'sanitize_text_field',
  ) );
  $wp_customize->add_control( new Prefix_Custom_Content( $wp_customize, $set, array(
  	'section'     => 'stp_color',
  	'label'       => __( '<div class="stp-title">メインメニュー</div>', 'stepress' ),
  ) ) );

  // メインメニュー：背景色
  $set = 'customize_hmenu_bgcolor';
  $wp_customize->add_setting( $set, array(
    'default'     => '#fff',
  ) );
  $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, $set, array(
    'label'       => __( '背景色', 'stepress' ),
    'section'     => 'stp_color',
    'settings'    => $set,
  ) ) );

  // メインメニュー：背景色（ホバー）
  $set = 'customize_hmenu_hover_bgcolor';
  $wp_customize->add_setting( $set, array(
    'default'     => '#fbfbfb',
  ) );
  $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, $set, array(
    'label'       => __( '背景色（ホバー）', 'stepress' ),
    'section'     => 'stp_color',
    'settings'    => $set,
  ) ) );

  // メインメニュー：背景色（アクティブな項目）
  $set = 'customize_hmenu_on_bgcolor';
  $wp_customize->add_setting( $set, array(
    'default'     => '#fff',
  ) );
  $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, $set, array(
    'label'       => __( '背景色（アクティブな項目）', 'stepress' ),
    'section'     => 'stp_color',
    'settings'    => $set,
  ) ) );

  // -----------------------------------------------------------------------------------------------

  $set = 'customize_hr_hmenu_color';
  $wp_customize->add_setting( $set, array(
    'sanitize_callback' => 'sanitize_text_field',
  ) );
  $wp_customize->add_control( new Prefix_Custom_Content( $wp_customize, $set, array(
  	'label'       => '<hr>',
  	'section'     => 'stp_color',
  ) ) );

  // メインメニュー：文字色
  $set = 'customize_hmenu_color';
  $wp_customize->add_setting( $set, array(
    'default'     => '#000',
  ) );
  $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, $set, array(
    'label'       => __( '文字色', 'stepress' ),
    'section'     => 'stp_color',
    'settings'    => $set,
  ) ) );

  // メインメニュー：文字色（ホバー）
  $set = 'customize_hmenu_hover_color';
  $wp_customize->add_setting( $set, array(
    'default'     => '#000',
  ) );
  $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, $set, array(
    'label'       => __( '文字色（ホバー）', 'stepress' ),
    'section'     => 'stp_color',
    'settings'    => $set,
  ) ) );

  // メインメニュー：文字色（アクティブな項目）
  $set = 'customize_hmenu_on_color';
  $wp_customize->add_setting( $set, array(
    'default'     => '#000',
  ) );
  $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, $set, array(
    'label'       => __( '文字色（アクティブな項目）', 'stepress' ),
    'section'     => 'stp_color',
    'settings'    => $set,
  ) ) );


  // -----------------------------------------------------------------------------------------------

  $set = 'customize_hr_hmenu_border_color';
  $wp_customize->add_setting( $set, array(
    'sanitize_callback' => 'sanitize_text_field',
  ) );
  $wp_customize->add_control( new Prefix_Custom_Content( $wp_customize, $set, array(
  	'section'     => 'stp_color',
  	'label'       => '<hr>',
  ) ) );

  // メインメニュー：ボーダー色（アクティブな項目）
  $set = 'customize_hmenu_on_border_color';
  $wp_customize->add_setting( $set, array(
    'default'     => '#1e73be',
  ) );
  $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, $set, array(
    'label'       => __( 'ボーダー色（アクティブな項目）', 'stepress' ),
    'section'     => 'stp_color',
    'settings'    => $set,
  ) ) );

  // メインメニュー：ボーダー（アクティブな項目）を表示する
  $set = 'customize_hmenu_on_border_show';
  $wp_customize->add_setting( $set, array(
    'default'     => true,
  ) );
  $wp_customize->add_control( $set, array(
    'label'       => __( '表示する', 'stepress' ),
    'section'     => 'stp_color',
    'type'        => 'checkbox',
    'settings'    => $set,
  ) );

  // -----------------------------------------------------------------------------------------------

  $set = 'customize_hr_hmenu_border';
  $wp_customize->add_setting( $set, array(
    'sanitize_callback' => 'sanitize_text_field',
  ) );
  $wp_customize->add_control( new Prefix_Custom_Content( $wp_customize, $set, array(
  	'section'     => 'stp_color',
  	'label'       => '<hr>',
  ) ) );

  // メインメニュー：ボーダー色（ボタンの区切り線）
  $set = 'customize_hmenu_border_lr_color';
  $wp_customize->add_setting( $set, array(
    'default'     => '#f1f1f1',
  ) );
  $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, $set, array(
    'label'       => __( 'ボーダー色（ボタンの区切り線）', 'stepress' ),
    'section'     => 'stp_color',
    'settings'    => $set,
  ) ) );

  // メインメニュー：ボーダー（ボタンの区切り線）を表示する
  $set = 'customize_hmenu_border_lr_show';
  $wp_customize->add_setting( $set, array(
    'default'     => true,
  ) );
  $wp_customize->add_control( $set, array(
    'label'       => __( '表示する', 'stepress' ),
    'section'     => 'stp_color',
    'type'        => 'checkbox',
    'settings'    => $set,
  ) );

  // メインメニュー：ボーダー色（メニューの上）
  $set = 'customize_hmenu_border_t_color';
  $wp_customize->add_setting( $set, array(
    'default'     => '#e1e1e1',
  ) );
  $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, $set, array(
    'label'       => __( 'ボーダー色（メインメニューの上）', 'stepress' ),
    'section'     => 'stp_color',
    'settings'    => $set,
  ) ) );

  // メインメニュー：ボーダー（メインメニューの上）を表示する
  $set = 'customize_hmenu_border_t_show';
  $wp_customize->add_setting( $set, array(
    'default'     => true,
  ) );
  $wp_customize->add_control( $set, array(
    'label'       => __( '表示する', 'stepress' ),
    'section'     => 'stp_color',
    'type'        => 'checkbox',
    'settings'    => $set,
  ) );


  // ウィジェットタイトル
  // -----------------------------------------------------------------------------------------------
  $set = 'customize_group_widget_title_color';
  $wp_customize->add_setting( $set, array(
    'sanitize_callback' => 'sanitize_text_field',
  ) );
  $wp_customize->add_control( new Prefix_Custom_Content( $wp_customize, $set, array(
  	'section'     => 'stp_color',
  	'label'       => __( '<div class="stp-title">ウィジェットタイトル</div>', 'stepress' ),
  ) ) );

  // ボーダー色
  $set = 'customize_widget_title_border_color';
  $wp_customize->add_setting( $set, array(
    'default'     => '#1e73be',
  ) );
  $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, $set, array(
    'label'       => __( 'ボーダー色', 'stepress' ),
    'section'     => 'stp_color',
    'settings'    => $set,
  ) ) );


  // 見出し（記事本文内）
  // -----------------------------------------------------------------------------------------------
  $set = 'customize_group_title_color';
  $wp_customize->add_setting( $set, array(
    'sanitize_callback' => 'sanitize_text_field',
  ) );
  $wp_customize->add_control( new Prefix_Custom_Content( $wp_customize, $set, array(
  	'section'     => 'stp_color',
  	'label'       => __( '<div class="stp-title">見出し（記事本文内）</div>', 'stepress' ),
  ) ) );

  // ボーダー色
  $set = 'customize_title_border_color';
  $wp_customize->add_setting( $set, array(
    'default'     => '#1e73be',
  ) );
  $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, $set, array(
    'label'       => __( 'ボーダー色', 'stepress' ),
   	'description' => __( '本文 &lt;h2&gt;  &lt;h3&gt; &lt;h4&gt;', 'stepress' ),
    'section'     => 'stp_color',
    'settings'    => $set,
  ) ) );

  // -----------------------------------------------------------------------------------------------

  $set = 'customize_hr_title_color';
  $wp_customize->add_setting( $set, array(
    'sanitize_callback' => 'sanitize_text_field',
  ) );
  $wp_customize->add_control( new Prefix_Custom_Content( $wp_customize, $set, array(
  	'section'     => 'stp_color',
  	'label'       => '<hr>',
  ) ) );

  // 見出し2の背景色
  $set = 'customize_title2_bgcolor';
  $wp_customize->add_setting( $set, array(
    'default'     => '#f5f5f5',
  ) );
  $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, $set, array(
    'label'       => __( '背景色', 'stepress' ),
   	'description' => __( '本文 &lt;h2&gt;', 'stepress' ),
    'section'     => 'stp_color',
    'settings'    => $set,
  ) ) );

  // 見出し2の文字色
  $set = 'customize_title2_color';
  $wp_customize->add_setting( $set, array(
    'default'     => '#000',
  ) );
  $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, $set, array(
    'label'       => __( '文字色', 'stepress' ),
   	'description' => __( '本文 &lt;h2&gt;', 'stepress' ),
    'section'     => 'stp_color',
    'settings'    => $set,
  ) ) );


  // カテゴリーラベル
  // -----------------------------------------------------------------------------------------------
  $set = 'customize_group_post_color';
  $wp_customize->add_setting( $set, array(
    'sanitize_callback' => 'sanitize_text_field',
  ) );
  $wp_customize->add_control( new Prefix_Custom_Content( $wp_customize, $set, array(
  	'section'     => 'stp_color',
  	'label'       => __( '<div class="stp-title">カテゴリーラベル</div>', 'stepress' ),
  ) ) );

  // 背景色
  $set = 'customize_category_color';
  $wp_customize->add_setting( $set, array(
    'default'     => '#1e73be',
  ) );
  $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, $set, array(
    'label'       => __( 'カテゴリーラベル（投稿）', 'stepress' ),
    'section'     => 'stp_color',
    'settings'    => $set,
  ) ) );


  // フッター
  // -----------------------------------------------------------------------------------------------
  $set = 'customize_group_footer';
  $wp_customize->add_setting( $set, array(
    'sanitize_callback' => 'sanitize_text_field',
  ) );
  $wp_customize->add_control( new Prefix_Custom_Content( $wp_customize, $set, array(
  	'section'     => 'stp_color',
  	'label'       => __( '<div class="stp-title">フッター</div>', 'stepress' ),
   	'description' => __( 'ウィンドウ幅 600px 以下（スマートフォン用レイアウト）では反映されません。', 'stepress' ),
  ) ) );

  // フッター：背景色
  $set = 'customize_footer_bgcolor';
  $wp_customize->add_setting( $set, array(
    'default'     => '#fff',
  ) );
  $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, $set, array(
    'label'       => __( '背景色', 'stepress' ),
    'section'     => 'stp_color',
    'settings'    => $set,
  ) ) );

  // -----------------------------------------------------------------------------------------------

  $set = 'customize_hr_footer_border_color';
  $wp_customize->add_setting( $set, array(
    'sanitize_callback' => 'sanitize_text_field',
  ) );
  $wp_customize->add_control( new Prefix_Custom_Content( $wp_customize, $set, array(
  	'section'     => 'stp_color',
  	'label'       => '<hr>',
  ) ) );

  // フッター：ボーダー色（フッターの上）
  $set = 'customize_footer_border_t_color';
  $wp_customize->add_setting( $set, array(
    'default'     => '#d1d1d1',
  ) );
  $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, $set, array(
    'label'       => __( 'ボーダー色（フッターの上）', 'stepress' ),
    'section'     => 'stp_color',
    'settings'    => $set,
  ) ) );

  // フッター：ボーダー（フッターの上）を表示する
  $set = 'customize_footer_border_t_show';
  $wp_customize->add_setting( $set, array(
    'default'     => true,
  ) );
  $wp_customize->add_control( $set, array(
    'label'       => __( '表示する', 'stepress' ),
    'section'     => 'stp_color',
    'type'        => 'checkbox',
    'settings'    => $set,
  ) );



  // セクション：レイアウト

  // 基本レイアウト
  // -----------------------------------------------------------------------------------------------
  $set = 'customize_group_layout';
  $wp_customize->add_setting( $set, array(
    'sanitize_callback' => 'sanitize_text_field',
  ) );
  $wp_customize->add_control( new Prefix_Custom_Content( $wp_customize, $set, array(
  	'section'     => 'stp_layout',
  	'label'       => __( '<div class="stp-title stp-title--first">基本レイアウト</div>', 'stepress' ),
    'description' => __( 'ウィンドウ幅 961px 以上（デスクトップ）での表示設定です。<br>タイプCは背景設定がカバー画像の左右に広がる帯部分に適用されます。<br>タイプDは背景設定が適用されません。' ),
  ) ) );

  // レイアウトタイプ
  $set = 'customize_layout_type';
  $wp_customize->add_setting( $set, array(
    'default'     => 'a',
  ) );
  $wp_customize->add_control( $set, array(
    'label'       => __( 'レイアウトタイプ', 'stepress' ),
    'section'     => 'stp_layout',
    'type'        => 'select',
    'settings'    => $set,
		'choices' => array(
			'a' => 'タイプA',
			'b' => 'タイプB',
			'c' => 'タイプC',
			'd' => 'タイプD',
		),
  ) );

  // サイドバーの位置
  $set = 'customize_sidebar';
  $wp_customize->add_setting( $set, array(
    'default'     => 'right',
  ) );
  $wp_customize->add_control( $set, array(
    'label'       => __( 'サイドバーの位置', 'stepress' ),
    'section'     => 'stp_layout',
    'type'        => 'select',
    'settings'    => $set,
		'choices' => array(
			'left'  => '左',
			'right' => '右',
			'none'  => '表示しない（1カラム）',
		),
  ) );

  // ヘッダーに検索フォームを表示する
  $set = 'customize_header_search_show';
  $wp_customize->add_setting( $set, array(
    'default'     => true,
  ) );
  $wp_customize->add_control( $set, array(
    'label'       => __( 'ヘッダーに検索フォームを表示する', 'stepress' ),
    'section'     => 'stp_layout',
    'type'        => 'checkbox',
    'settings'    => $set,
  ) );


  // サイズ設定
  // -----------------------------------------------------------------------------------------------
  $set = 'customize_group_size';
  $wp_customize->add_setting( $set, array(
    'sanitize_callback' => 'sanitize_text_field',
  ) );
  $wp_customize->add_control( new Prefix_Custom_Content( $wp_customize, $set, array(
  	'section'     => 'stp_layout',
  	'label'       => __( '<div class="stp-title stp-title">基本サイズ</div>', 'stepress' ),
    'description' => __( 'ウィンドウ幅 961px 以上（デスクトップ）で基準となるサイズです。 / 単位 = px', 'stepress' ),
  ) ) );

  // ヘッダーの高さ
  $set = 'customize_header_height';
  $wp_customize->add_setting( $set, array(
    'default'     => '80',
  ) );
  $wp_customize->add_control( $set, array(
    'label'       => __( 'ヘッダーの高さ', 'stepress' ),
    'description' => __( '初期値：80', 'stepress' ),
    'section'     => 'stp_layout',
    'settings'    => $set,
    'type'        => 'number',
  ) );

  // メインメニューの高さ
  $set = 'customize_hmenu_height';
  $wp_customize->add_setting( $set, array(
    'default'     => '60',
  ) );
  $wp_customize->add_control( $set, array(
    'label'       => __( 'メインメニューの高さ', 'stepress' ),
    'description' => __( '初期値：60', 'stepress' ),
    'section'     => 'stp_layout',
    'settings'    => $set,
    'type'        => 'number',
  ) );

  // コンテンツの幅
  $set = 'customize_content_width';
  $wp_customize->add_setting( $set, array(
    'default'     => '640',
  ) );
  $wp_customize->add_control( $set, array(
    'label'       => __( '記事エリアの幅', 'stepress' ),
    'description' => __( '初期値：640', 'stepress' ),
    'section'     => 'stp_layout',
    'settings'    => $set,
    'type'        => 'number',
  ) );

  // サイドバーの幅
  $set = 'customize_side_width';
  $wp_customize->add_setting( $set, array(
    'default'     => '300',
  ) );
  $wp_customize->add_control( $set, array(
    'label'       => __( 'サイドバーの幅', 'stepress' ),
    'description' => __( '初期値：300', 'stepress' ),
    'section'     => 'stp_layout',
    'settings'    => $set,
    'type'        => 'number',
  ) );


  // メインメニュー（スマートフォン）
  // -----------------------------------------------------------------------------------------------
  $set = 'customize_group_hmenu_layout-sp';
  $wp_customize->add_setting( $set, array(
    'sanitize_callback' => 'sanitize_text_field',
  ) );
  $wp_customize->add_control( new Prefix_Custom_Content( $wp_customize, $set, array(
  	'section'     => 'stp_layout',
  	'label'       => __( '<div class="stp-title">メインメニュー（スマートフォン）</div>', 'stepress' ),
    'description' => __( 'スマートフォン用の表示設定です。<b>【ドロワーメニューに入れる】</b>を選択すると左上のボタン内にまとめられます。', 'stepress' ),
  ) ) );

  // メインメニュー
  $set = 'customize_hmenu_style_sp';
  $wp_customize->add_setting( $set, array(
    'default'     => '2',
  ) );
  $wp_customize->add_control( $set, array(
    'section'     => 'stp_layout',
    'type'        => 'select',
    'settings'    => $set,
		'choices' => array(
			'2' => '2個ごとに折り返す',
			'3' => '3個ごとに折り返す',
			'4' => '4個ごとに折り返す',
			'0' => '折り返さない',
			'1' => 'ドロワーメニューに入れる',
		),
  ) );


  // パンくずリスト
  // -----------------------------------------------------------------------------------------------
  $set = 'customize_group_breadcrumb';
  $wp_customize->add_setting( $set, array(
    'sanitize_callback' => 'sanitize_text_field',
  ) );
  $wp_customize->add_control( new Prefix_Custom_Content( $wp_customize, $set, array(
  	'section'     => 'stp_layout',
  	'label'       => __( '<div class="stp-title stp-title">パンくずリスト</div>', 'stepress' ),
  ) ) );

  // パンくずリストを表示する
  $set = 'customize_breadcrumb';
  $wp_customize->add_setting( $set, array(
    'default'     => true,
  ) );
  $wp_customize->add_control( $set, array(
    'label'       => __( 'パンくずリストを表示する', 'stepress' ),
    'section'     => 'stp_layout',
    'type'        => 'checkbox',
    'settings'    => $set,
  ) );

  // トップページ表記
  $set = 'customize_breadcrumb_home';
  $wp_customize->add_setting( $set, array(
    'default'     => 'ホーム',
  ) );
  $wp_customize->add_control( $set, array(
    'label'       => __( 'トップページ表記', 'stepress' ),
    'description' => __( '初期値：ホーム', 'stepress' ),
    'section'     => 'stp_layout',
    'settings'    => $set,
    'type'        => 'text',
  ) );


  // 投稿一覧
  // -----------------------------------------------------------------------------------------------
  $set = 'customize_group_summary';
  $wp_customize->add_setting( $set, array(
    'sanitize_callback' => 'sanitize_text_field',
  ) );
  $wp_customize->add_control( new Prefix_Custom_Content( $wp_customize, $set, array(
  	'section'     => 'stp_layout',
  	'label'       => __( '<div class="stp-title">投稿一覧</div>', 'stepress' ),
  ) ) );

  // 投稿一覧：アイキャッチ画像の位置
  $set = 'customize_eyecatch_summary';
  $wp_customize->add_setting( $set, array(
    'default'     => 'left',
  ) );
  $wp_customize->add_control( $set, array(
    'label'       => __( 'アイキャッチ画像の位置', 'stepress' ),
    'section'     => 'stp_layout',
    'type'        => 'select',
    'settings'    => $set,
		'choices' => array(
			'left'    => '左',
			'left2'   => '左：画像がない場合は代替画像',
			'right'   => '右',
			'right2'  => '右：画像がない場合は代替画像',
			'none'    => '表示しない',
		),
  ) );

  // 投稿一覧：シェアボタンの位置
  $set = 'customize_sns_position_summary';
  $wp_customize->add_setting( $set, array(
    'default'     => 'bottom',
  ) );
  $wp_customize->add_control( $set, array(
    'label'       => __( 'シェアボタンの位置', 'stepress' ),
    'section'     => 'stp_layout',
    'type'        => 'select',
    'settings'    => $set,
		'choices' => array(
			'top'    => '上',
			'bottom' => '下',
			'all'    => '上と下',
			'none'   => '表示しない',
		),
  ) );


  // 投稿
  // -----------------------------------------------------------------------------------------------
  $set = 'customize_group_post';
  $wp_customize->add_setting( $set, array(
    'sanitize_callback' => 'sanitize_text_field',
  ) );
  $wp_customize->add_control( new Prefix_Custom_Content( $wp_customize, $set, array(
  	'section'     => 'stp_layout',
  	'label'       => __( '<div class="stp-title">投稿</div>', 'stepress' ),
  ) ) );

  // 投稿：アイキャッチ画像の位置
  $set = 'customize_eyecatch_position_post';
  $wp_customize->add_setting( $set, array(
    'default'     => 'bottom',
  ) );
  $wp_customize->add_control( $set, array(
    'label'       => __( 'アイキャッチ画像の位置', 'stepress' ),
    'section'     => 'stp_layout',
    'type'        => 'select',
    'settings'    => $set,
		'choices' => array(
			'top'    => 'タイトルの上',
			'bottom' => 'タイトルの下',
			'none'   => '表示しない',
		),
  ) );

  // 投稿：シェアボタンの位置
  $set = 'customize_sns_position_post';
  $wp_customize->add_setting( $set, array(
    'default'     => 'bottom',
  ) );
  $wp_customize->add_control( $set, array(
    'label'       => __( 'シェアボタンの位置', 'stepress' ),
    'section'     => 'stp_layout',
    'type'        => 'select',
    'settings'    => $set,
		'choices' => array(
			'top'    => '本文の上',
			'bottom' => '本文の下',
			'all'    => '本文の上と下',
			'none'   => '表示しない',
		),
  ) );

  // 投稿：先頭にページ送りを表示する
  $set = 'customize_articlepager';
  $wp_customize->add_setting( $set, array(
    'default'     => 'checked',
  ) );
  $wp_customize->add_control( $set, array(
    'label'       => __( '先頭にページ送りを表示する', 'stepress' ),
    'section'     => 'stp_layout',
    'type'        => 'checkbox',
    'settings'    => $set,
  ) );



  // 固定ページ
  // -----------------------------------------------------------------------------------------------
  $set = 'customize_group_page';
  $wp_customize->add_setting( $set, array(
    'sanitize_callback' => 'sanitize_text_field',
  ) );
  $wp_customize->add_control( new Prefix_Custom_Content( $wp_customize, $set, array(
  	'section'     => 'stp_layout',
  	'label'       => __( '<div class="stp-title">固定ページ</div>', 'stepress' ),
  ) ) );

  // 固定ページ：アイキャッチ画像の位置
  $set = 'customize_eyecatch_position_page';
  $wp_customize->add_setting( $set, array(
    'default'     => 'bottom',
  ) );
  $wp_customize->add_control( $set, array(
    'label'       => __( 'アイキャッチ画像の位置', 'stepress' ),
    'section'     => 'stp_layout',
    'type'        => 'select',
    'settings'    => $set,
		'choices' => array(
			'top'    => 'タイトルの上',
			'bottom' => 'タイトルの下',
			'none'   => '表示しない',
		),
  ) );

  // 固定ページ：シェアボタンの位置
  $set = 'customize_sns_position_page';
  $wp_customize->add_setting( $set, array(
    'default'     => 'bottom',
  ) );
  $wp_customize->add_control( $set, array(
    'label'       => __( 'シェアボタンの位置', 'stepress' ),
    'section'     => 'stp_layout',
    'type'        => 'select',
    'settings'    => $set,
		'choices' => array(
			'top'    => '本文の上',
			'bottom' => '本文の下',
			'all'    => '本文の上と下',
			'none'   => '表示しない',
		),
  ) );

}
add_action('customize_register', 'stp_customize_register' );

