<?php

/**
 * 最近の投稿＋（アイキャッチ画像・カテゴリー絞り込み）
 */

class RecentPostPlusWidget extends WP_Widget {

  function RecentPostPlusWidget() {
    $widget_ops = array(
      'description' => __( '投稿一覧を様々な形式で表示する、ステップレスの独自ウィジェットです。', 'stepress' )
    );
    $this->WP_Widget( 'recent_entries_plus', __( '最近の投稿＋', 'stepress' ), $widget_ops);
  }

  function form( $instance ) {
    $defaults = array(
      'style' => 'overwrap',
      'limit' => 5,
      'width' => 100,
      'height' => 100,
    );
    $instance = wp_parse_args( ( array ) $instance, $defaults );

    ?>
    <p>
      <label for="<?php echo $this->get_field_id( 'title' ); ?>">
        <?php _e( 'タイトル:', 'stepress' ); ?>
      </label>
      <input id="<?php echo $this->get_field_id( 'title' ); ?>"
             class="widefat title"
             type="text"
             name="<?php echo $this->get_field_name('title' ); ?>"
             value="<?php echo $instance['title']; ?>">
    </p>
    <p>
      <label for="<?php echo $this->get_field_id( 'cat' ); ?>">
        <?php _e( 'カテゴリー:', 'stepress' ); ?>
      </label>
      <?php wp_dropdown_categories( array(
              'taxonomy'         => 'category',
              'name'             => $this->get_field_name('cat' ),
              'id'               => $this->get_field_id( 'cat' ),
              'show_option_none' => __( 'カテゴリーを指定しない', 'stepress' ),
              'selected'         => $instance['cat'] ) ); ?>
    </p>
    <p>
      <label for="<?php echo $this->get_field_id( 'limit' ); ?>">
        <?php _e( '表示する投稿数:', 'stepress' ); ?>
      </label>
      <input id="<?php echo $this->get_field_id( 'limit' ); ?>"
             name="<?php echo $this->get_field_name('limit' ); ?>"
             class="tiny-text"
             type="number"
             step="1"
             min="1"
             size="3"
             value="<?php echo $instance['limit']; ?>">
    </p>
    <p>
      <label for="<?php echo $this->get_field_id( 'eyecatch' ); ?>">
        <?php _e( 'アイキャッチ画像の位置:', 'stepress' ); ?>
      </label>
      <select name="<?php echo $this->get_field_name('eyecatch' ); ?>" id="<?php echo $this->get_field_id( 'style' ); ?>">
        <?php
          // アイキャッチ画像の位置
          $data = array(
            array( 'left',   __( '左', 'stepress' ) ),
            array( 'left2',  __( '左（ない場合は代替画像）', 'stepress' ) ),
            array( 'right',  __( '右', 'stepress' ) ),
            array( 'right2', __( '右（ない場合は代替画像）', 'stepress' ) ),
            array( 'none',   __( '表示しない', 'stepress' ) ),
          );
          foreach ( $data as $d) {
            if ( $d[0] == esc_attr( $instance['eyecatch'] ) ) {
              $d[2] = 'selected';
            }
            echo '<option value="' . $d[0] . '" ' . $d[2] . '>' . $d[1] . '</option>';
          }
        ?>
      </select>
    </p>
    <p>
      <input id="<?php echo $this->get_field_id( 'show_date' ); ?>"
             name="<?php echo $this->get_field_name('show_date' ); ?>"
             class="checkbox"
             type="checkbox"
             value="1"
             <?php checked('1', esc_attr( $instance['show_date'] ) ); ?>>
      <label for="<?php echo $this->get_field_id( 'show_date' ); ?>">
        <?php _e( '投稿日を表示', 'stepress' ); ?>
      </label>
    </p>
    <?php
  }


  function widget( $args, $instance ) {
    extract( $args );

    // タイトル
    if ( $instance['title'] != '' ) {
      $title    = apply_filters('widget_title', $instance['title'] );
    } else {
      $title = __( '最近の投稿', 'stepress' );
    }
    echo $before_widget . $before_title . $title . $after_title;

    $show_date = apply_filters('widget_show_date', $instance['show_date'] );
    ?>
      <?php
      $args = array(
        'post_type'           => 'post',
        'posts_per_page'      => $instance['limit'],
        'cat'                 => $instance['cat'],
        'ignore_sticky_posts' => '1', // 先頭固定無効
      );
      if ( $instance['cat'] == -1 ) unset( $args['cat'] ); // カテゴリー未指定の場合
      $st_query = new WP_Query( $args);


      // アイキャッチ画像の位置
      switch ( $instance['eyecatch'] ) {
        case 'right':
        case 'right2':
          $layout = 'right';
          break;
        case 'none':
          $layout = 'none';
          break;
        default:
          $layout = 'left';
          break;
      }

      // アイキャッチがない場合に代替画像を表示
      switch ( $instance['eyecatch'] ) {
        case 'left':
        case 'right':
        case 'none':
          $dummy  = null; // 表示しない
          break;
        default:
          $dummy  = 1; // 表示する
          break;
      }

      // アイキャッチ非表示で日付を表示する場合横並びにする
      if ( $instance['show_date'] && ( $instance['eyecatch'] == 'none' )  ) {
        $date_style  = 'inline';
      } else {
        $date_style  = 'block';
      }
      ?>
      <ul class="widget-summary widget-summary--<?php echo $date_style; ?>">
        <?php while ( $st_query->have_posts() ): $st_query->the_post(); ?>
          <li class="widget-summary__article">
            <a href="<?php the_permalink(); ?>" class="widget-summary__link">
              <?php if ( has_post_thumbnail() && ( $layout == 'left' || $layout == 'right' ) ): ?>
                <div class="widget-summary__eyecatch widget-summary__eyecatch--<?php echo $layout; ?>">
                  <?php the_post_thumbnail( 'thumbnail' ); ?>
                </div>
              <?php elseif ( isset( $dummy ) ): // 代替画像 ?>
                <div class="widget-summary__eyecatch widget-summary__eyecatch--<?php echo $layout; ?>">
                  <img src="<?php echo get_template_directory_uri(); ?>/images/no-image.png" width="150">
                </div>
              <?php endif; ?>
              <div class="widget-summary__text">
                <div class="widget-summary__text__title">
                  <?php the_title(); // 記事タイトル ?>
                </div>
                <?php if ( $instance['show_date'] ): // 投稿日 ?>
                  <time datetime="<?php the_time( 'c' ); ?>" class="widget-summary__text__date">
                    <?php the_time( get_option( 'date_format' ) ); ?>
                  </time>
                <?php endif; ?>
              </div>
            </a>
          </li>
        <?php endwhile; ?>
      </ul>
      <?php wp_reset_postdata(); ?>
    <?php
    echo $after_widget;
  }

  function update( $new_instance, $old_instance) {
    $instance = $old_instance;
    $instance['title']     = strip_tags( $new_instance['title'] );
    $instance['cat']       = $new_instance['cat'];
    $instance['eyecatch']  = $new_instance['eyecatch'];
    $instance['show_date'] = $new_instance['show_date'];
    $instance['limit']     = is_numeric( $new_instance['limit'] ) ? $new_instance['limit'] : 6;
    return $instance;
  }
}

add_action('widgets_init', create_function('', 'return register_widget("RecentPostPlusWidget");' ) );




